HotLoot = LibStub("AceAddon-3.0"):NewAddon("HotLoot", "AceConsole-3.0", "AceEvent-3.0")

function HotLoot:createMainFrame()
	HotLoot.mainFrame = CreateFrame("Frame", "mainFrame", UIParent);
	HotLoot.mainFrame:SetWidth(32);
	HotLoot.mainFrame:SetHeight(24);
	--mainFrame:SetFrameStrata("DIALOG");
	HotLoot.mainFrame:SetPoint("CENTER", 0, 0);
	HotLoot.mainFrame:SetScript("OnUpdate", FadeItems);
	
	HotLoot.mainFrame.mainBG = HotLoot.mainFrame:CreateTexture("mainBG", "BACKGROUND");
	HotLoot.mainFrame.mainBG:SetAllPoints(HotLoot.mainFrame);
	HotLoot.mainFrame.mainBG:SetTexture(0.1, 0.1, 0.1, 0.7);
	
	HotLoot.mainFrame.anchorText = HotLoot.mainFrame:CreateFontString(nil, "OVERLAY");
	HotLoot.mainFrame.anchorText:SetPoint("CENTER", HotLoot.mainFrame, "CENTER", 0, 0);
	HotLoot.mainFrame.anchorText:SetFont(STANDARD_TEXT_FONT, 9, "OUTLINE");
	--name:SetJustifyH("LEFT");
	HotLoot.mainFrame.anchorText:SetText("ANCHOR");
	
	HotLoot.mainFrame:RegisterForDrag("LeftButton");
	HotLoot.mainFrame:SetMovable(true);
	HotLoot.mainFrame:EnableMouse(true);
	HotLoot.mainFrame:SetScript("OnDragStart", HotLoot.mainFrame.StartMoving);
	HotLoot.mainFrame:SetScript("OnDragStop", HotLoot.mainFrame.StopMovingOrSizing);
	HotLoot.mainFrame:Show();
end	

-- options select table
local closeKeyTable = {
	["ctrl"] = "Control",
	["shift"] = "Shift",
	["alt"] = "Alt"
}

local growthDirectionTable = {
	[1] = "Up",
	[-1] = "Down"
}

-- options
local options = {
    name = "HotLoot",
    handler = HotLoot,
    type = "group",
    args = {
		lootDesc = {
			name = "HotLoot is an autoloot filter designed to streamline the looting process. This AddOn allow you to automatically loot various items related to professions and quests.\n",			
			type = "description",
			order = 0
		},
		lootDesc3 = {
			name = "NOTE: In order for HotLoot to work effectively please ensure that all other autoloot AddOns and options are turned off.\n",  
			type = "description",
			order = 2
		},
		groupSystem = {
			name = "System",
			type = "group",
			order = 4,
			args = {
				lootEnabled = {
					name = "Enable",
					desc = "check to enable HotLoot",
					type = "toggle",
					set = "setLootEnabled",
					get = "getLootEnabled",
					order = 1
				},
				lootDebug = {
					name = "Debug Mode",
					desc = "Check to enable debugging.",
					type = "toggle",
					set = "setLootDebug",
					get = "getLootDebug",
					order = 2
				},
				lootClose = {
					name = "Close Loot Window",
					desc = "Check to automatically close the loot window after autolooting\n\nHold |cFFFFCC00Ctrl|r (or whichever key you choose) to temporarily disable while looting.",
					type = "toggle",
					set = "setLootClose",
					get = "getLootClose",
					order = 3
				},
				lootCloseKey = {
					name = "Close Loot Window Modifier Key",
					desc = "Here you can choose the modifier key to disable auto closing the loot window.",
					type = "select",
					values = closeKeyTable,
					set = "setLootCloseKey",
					get = "getLootCloseKey",
					order = 4
				},
			}, 
		},
		goupLootMonitor = {
			name = "Loot Monitor", 
			type = "group", 
			order = 5, 
			args = {
				lootEnableMonitor = {
					name = "Enable Loot Monitor",
					--desc = " ",
					type = "toggle",
					set = "setLootEnableMonitor",
					get = "getLootEnableMonitor",
					order = 1
				},
				lootShowAnchor = {
					name = "Show Anchor",
					desc = "Shows the anchor so you can move the Loot Monitor.",
					desc = "Shows the anchor so you can move the Loot Monitor.",
					type = "toggle",
					set = "setLootShowAnchor",
					get = "getLootShowAnchor",
					order = 2
				},
				lootShowNames = {
					name = "Show Item Names",
					desc = "Shows the item names next to the icons in the Loot Monitor.\n\n|cFFFF0000(must be off to use grid mode)|r",
					type = "toggle",
					set = "setLootShowNames",
					get = "getLootShowNames",
					order = 3
				},
				lootShowQuantities = {
					name = "Show Item Quantities",
					desc = "Shows the quantities of the items on top of icons in the Loot Monitor.",
					type = "toggle",
					set = "setLootShowQuantities",
					get = "getLootShowQuantities",
					order = 4
				},
				lootIconSize = {
					name = "Icon Size",
					desc = "Set the size of the Loot Monitor item icons in increments of 8.",
					type = "range",
					min = 8,
					max = 32,
					step = 8, 
					bigStep = 8,
					set = "setLootIconSize",
					get = "getLootIconSize",
					order = 5
				},
				lootGrowthDirection = {
					name = "Growth Direction",
					desc = "Here you can choose whether the monitor grows up or down.",
					type = "select",
					values = growthDirectionTable,
					set = "setLootGrowthDirection",
					get = "getLootGrowthDirection",
					order = 6
				},
				lootGridMode = {
					name = "Icon Grid Mode",
					desc = "Icons display in a grid style.\n\n|cFFFF0000(show names must be off)|r",
					type = "toggle",
					set = "setLootGridMode",
					get = "getLootGridMode",
					disabled = "ToggleGridDisable",
					order = 7
				},
				lootGridNumColumns = {
					name = "Grid Columns",
					type = "range",
					min = 1,
					max = 10,
					step = 1, 
					bigStep = 1,
					set = "setLootGridNumColumns",
					get = "getLootGridNumColumns",
					
					order = 8
				},
				lootTestMonitor = {
					name = "Test Monitor",
					--desc = " ",
					type = "execute",
					func = "TestMonitor", 
					order = 9
				},
				lootResetMonitor = {
					name = "Reset Anchor",
					--desc = " ",
					type = "execute",
					func = "ResetMonitor", 
					order = 10
				},
				lootDesc = {
					name = "\nNOTE: This monitor is designed to only show loot that is specifically looted automatically. It will not show items that you loot manually.",
					type = "description",
					order = 12,
				},
			}, 
		},
		groupGeneral = {
			name = "General",
			type = "group",
			order = 6,
			args = {
				lootGold = {
					name = "Loot Gold",
					desc = "Check to autoloot gold.",
					type = "toggle",
					set = "setLootGold",
					get = "getLootGold",
					order = 1
				},
				lootQuest = {
					name = "Loot Quest Items",
					desc = "Check to autoloot quest items.",
					type = "toggle",
					set = "setLootQuest",
					get = "getLootQuest",
					order = 2
				},
				lootJunk = {
					name = "Loot Junk", 
					desc = "Check to autoloot junk (grey items).",
					type = "toggle",
					set = "setLootJunk",
					get = "getLootJunk",
					order = 3
				},
			},
		},
		groupProfessions = {
			name = "Professions",
			type = "group",
			order = 7,
			args = {
				lootMining = {
					name = "Loot Mining",
					desc = "Check to autoloot mining items.",
					type = "toggle",
					set = "setLootMining",
					get = "getLootMining",
					order = 1
				},
				lootGems = {
					name = "Loot Gems",
					desc = "Check to autoloot gems.",
					type = "toggle",
					set = "setLootGems",
					get = "getLootGems",
					order = 2
				},
				lootHerbs = {
					name = "Loot Herbs",
					desc = "Check to autoloot herbs.",
					type = "toggle",
					set = "setLootHerbs",
					get = "getLootHerbs",
					order = 3
				},
				lootSkinning = {
					name = "Loot Leather",
					desc = "Check to autoloot leather.",
					type = "toggle",
					set = "setLootSkinning",
					get = "getLootSkinning",
					order = 4
				},
				lootFishing = {
					name = "Loot Fishing",
					desc = "Check to autoloot fishing.",
					type = "toggle",
					set = "setLootFishing",
					get = "getLootFishing",
					order = 5
				},
			}
		},
		groupDrops = {
			name = "Common Drops",
			type = "group",
			order = 8,
			args = {
				lootCloth = {
					name = "Loot Cloth",
					desc = "Check to autoloot cloth.",
					type = "toggle",
					set = "setLootCloth",
					get = "getLootCloth",
					order = 1
				},
				lootPots = {
					name = "Loot Potions",
					desc = "Check to autoloot potions.",
					type = "toggle",
					set = "setLootPots",
					get = "getLootPots",
					order = 2
				},
				lootMoH = {
					name = "Loot Motes of Harmony",
					desc = "Check to autoloot Motes of Harmony.",
					type = "toggle",
					set = "setLootMoH",
					get = "getLootMoH",
					order = 3
				},
				lootElemental = {
					name = "Loot Elemental",
					desc = "Check to autoloot Elemental items.\n(i.e. Mote of Water)",
					type = "toggle",
					set = "setLootElemental",
					get = "getLootElemental",
					order = 4
				},
				lootCurrency = {
					name = "Loot Currency",
					desc = "Check to autoloot Currency.\n(i.e. Lesser Charm of Good Fortune)",
					type = "toggle",
					set = "setLootCurrency",
					get = "getLootCurrency",
					order = 4
				},
			}
		},
		groupUncommon = {
			name = "Uncommon Items",
			type = "group",
			order = 9,
			args = {
				magicDesc1 = {
					name = "For now Uncommon and Rare quality items will only be able to be looted when not in a group.",			
					type = "description",
					order = 1,
				},
				lootGreen = {
					name = "Loot |cFF00FF00Uncommon|r Items",
					desc = "\nCheck to autoloot |cFF00FF00Uncommon|r items.",
					type = "toggle",
					set = "setLootGreen",
					get = "getLootGreen",
					order = 3,
				},	
			},
		},
		groupRare = {
			name = "Rare Items",
			type = "group",
			order = 10,
			args = {
				magicDesc3 = {
					name = "For now Uncommon and Rare quality items will only be looted when not in a group.\n",			
					type = "description",
					order = 1,
				},
				lootBlue = {
					name = "Loot |cFF0000FFRare|r Items",
					desc = "Check to autoloot |cFF0000FFRare|r items.",
					type = "toggle",
					set = "setLootBlue",
					get = "getLootBlue",
					order = 3,
				},
			},
		},
		groupInclude = {
			name = "Include List",
			type = "group",
			order = 11,
			args = {
				includeList = {
					name = "Here you can write items you want to include when autolooting.\n(ie. Linen Cloth, Iron Ore)",
					multiline = 7,
					type = "input",
					set = "setIncludeList",
					get = "getIncludeList",
					width = "full",
					order = 1
				},
			}
		},
		groupExclude = {
			name = "Exclude List",
			type = "group",
			order = 12,
			args = {
				excludeList = {
					name = "Here you can write items you want excluded from autolooting.\n(ie. Linen Cloth, Iron Ore)",
					multiline = 7,
					type = "input",
					set = "setExcludeList",
					get = "getExcludeList",
					width = "full",
					order = 1
				},
			}
		},
    },
}



-- Config Defaults
local defaults = {
	char = {
		minimap = {
			hide = false,
		},
		lootEnabled = true,
		lootDebug = false,
		lootClose = false,
		lootCloseKey = "ctrl",
		lootEnableMonitor = true,
		lootShowAnchor = true,
		lootShowNames = true, 
		lootShowQuantities = true, 
		lootIconSize = 32, 
		lootGrowthDirection = -1, 
		lootGridMode = false,
		lootGridNumColumns = 4,
		lootGold = true,
		lootQuest = false,
		lootJunk = false,
		lootJunkDel = false,
		lootCloth = false,
		lootMining = false,
		lootGems = false,
		lootHerbs = false,
		lootSkinning = false,
		lootFishing = false,
		lootPots = false,
		lootMoH = false,
		lootElemental = false,
		lootsetLootCurrency = false,
		lootGreen = false,
		lootGreenConfirm = false,
		lootBlue = false,
		lootBlueConfirm = false,
		lootCustom = false,
		excludeList = " ",
		includeList = " ",
	}
}


-- OnInitialize
function HotLoot:OnInitialize()
    self.db = LibStub("AceDB-3.0"):New("HotLootDB", defaults, true)
    LibStub("AceConfig-3.0"):RegisterOptionsTable("HotLoot", options)
    self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("HotLoot", "HotLoot")
    self:RegisterChatCommand("hl", "ChatCommand")
    self:RegisterChatCommand("hotloot", "ChatCommand")
end

-- OnEnable
function HotLoot:OnEnable()
	HotLoot:createMainFrame();
	tStart = 0;
	HotLoot:ToggleAnchor(HotLoot:getLootShowAnchor());
end

-- ChatCommand
function HotLoot:ChatCommand(input)
    if not input or input:trim() == "" then
        InterfaceOptionsFrame_OpenToCategory(self.optionsFrame);
		InterfaceOptionsFrame_OpenToCategory(self.optionsFrame);
    else
        LibStub("AceConfigCmd-3.0"):HandleCommand("hl", "HotLoot", input);
    end
end

-- debug mode
local function dBug(name, value)
	if (HotLoot:getLootDebug() == true) then
		print(tostring(name) .. " = " .. tostring(value));
	end
end

--local monitor = HotLoot.createMainFrame();
local icons = {};				

-- HotLoot autoloot modudle

local frame = CreateFrame("FRAME", "HotLootFrame");
frame:RegisterEvent("LOOT_OPENED");
local function eventHandler(self, event, ...)
	if (HotLoot:getLootEnabled() == true) then
		local arg1, numSlots, curSlot;
		numSlots = GetNumLootItems();
		arg1 = ...;
		curSlot = 1;
		
		local keyDown, modKey;
		modKey = HotLoot:getLootCloseKey();
		if (modKey == "ctrl") then 
			keyDown = IsControlKeyDown();
		elseif (modKey == "shift") then 
			keyDown = IsShiftKeyDown();
		elseif (modKey == "alt") then 
			keyDown = IsAltKeyDown();
		end
		
		
		
		
		--[[--------------------------------
		------LOOTING LOOP------------------
		----------------------------------]]
		while (curSlot <= numSlots) do
			local itemName, itemLink, itemRarity, itemLevel, itemMinLevel, itemType, itemSubType, itemStackCount, itemEquipLoc, itemTexture, itemSellPrice;
			local lootLink, isLooted, isGold;
			isGold = false;
			isLooted = false;
			local lootIcon, lootName, lootQuantity, rarity, locked;
			lootIcon, lootName, lootQuantity, rarity, locked = GetLootSlotInfo(curSlot);
			lootLink = GetLootSlotLink(curSlot);
			-- check if its gold or currency ####NOPE####
			if GetLootSlotType(curSlot) == 1 then					
				
				itemName, itemLink, itemRarity, itemLevel, itemMinLevel, itemType, itemSubType, itemStackCount, itemEquipLoc, itemTexture, itemSellPrice = GetItemInfo(lootLink);
			else
				itemName = lootName;
				itemLink = lootLink																		;
				itemTexture = lootIcon;
				itemType = " ";
				itemSubType = " ";
			end
			--[[
			if itemName == nil then
				itemName = "Currency";
				itemLink = "[Currency]";
				itemType = "Currency";
				itemSubType = "Currency";
			end
			]]
			
			
			-- Exclude List
			if (string.find(HotLoot:getExcludeList(), itemName) ~= nil) then   -- WANT STRING GOT NIL "FIND" (i think its fixed)
				-- Don't Loot
				if (HotLoot:getLootDebug() == true) then
					print("Slot " .. curSlot .. " (" .. itemLink .. ") has been excluded.");
				end
			else
			--[[-------------------------------------------------------
			-------------------LOOT SWITCH-----------------------------
			---------------------------------------------------------]]
			if 
				-- Gold
				(GetLootSlotType(curSlot) == 2) and (HotLoot:getLootGold() == true) then 
					--itemLink = lootLink;
					LootSlot(curSlot);
					isLooted = true;
					isGold = true;
			elseif
				-- Currency
				(GetLootSlotType(curSlot) == 3) and (HotLoot:getLootCurrency() == true) then 
					LootSlot(curSlot);
					isLooted = true;
			elseif
				-- Quest
				(itemType == "Quest") and (HotLoot:getLootQuest() == true) then 
					LootSlot(curSlot);
					isLooted = true;
			elseif
				-- Junk
				(itemSubType == "Junk") and (HotLoot:getLootJunk() == true) then 
					LootSlot(curSlot);
					isLooted = true;
					DeleteJunk(itemName);
			elseif
				-- Cloth
				(itemSubType == "Cloth") and (itemType == "Trade Goods") and (HotLoot:getLootCloth() == true) then 
					LootSlot(curSlot);
					isLooted = true;
			elseif
				-- Mining
				(itemSubType == "Metal & Stone") and (HotLoot:getLootMining() == true) then 
					LootSlot(curSlot);
					isLooted = true;
			elseif
				-- Gems
				(itemType == "Gem") and (HotLoot:getLootGems() == true) then 
					LootSlot(curSlot) ;
					isLooted = true;
			elseif
				-- Herbs
				(itemSubType == "Herb") and (HotLoot:getLootHerbs() == true) then 
					LootSlot(curSlot);
					isLooted = true;
			elseif
				-- Leather
				(itemSubType == "Leather") and (IsEquippableItem(itemLink) == nil) and (HotLoot:getLootSkinning() == true) then 
					LootSlot(curSlot);
					isLooted = true;
			elseif
				-- Fishing (-junk)
				(IsFishingLoot()) and (HotLoot:getLootFishing() == true) and (itemSubType ~= "Junk") then 
					LootSlot(curSlot);
					isLooted = true;
			elseif
				-- Pots
				(itemSubType == "Potion") and (HotLoot:getLootPots() == true) then 
					LootSlot(curSlot);
					isLooted = true;
			elseif
				-- Motes
				(itemSubType == "Elemental") and (HotLoot:getLootElemental() == true) then 
					LootSlot(curSlot);
					isLooted = true;
			elseif
				-- MoH
				(itemName == "Mote of Harmony") and (HotLoot:getLootMoH() == true) then 
					LootSlot(curSlot);
					isLooted = true;
			elseif
				-- Include List
				(string.find(HotLoot:getIncludeList(), itemName) ~= nil) then 
					LootSlot(curSlot);
					isLooted = true;
			elseif
				-- Greens
				(IsInGroup() == false) and (HotLoot:getLootGreen() == true) and (itemRarity == 2) then 
					LootSlot(curSlot);
					isLooted = true;
					if (HotLoot:getLootGreenConfirm() == true) then ConfirmBindOnUse() end
			elseif
				-- Blues
				(IsInGroup() == false) and (HotLoot:getLootBlue() == true) and (itemRarity == 3) then 
					LootSlot(curSlot);
					isLooted = true;
					if (HotLoot:getLootBlueConfirm() == true) then ConfirmBindOnUse() end
			end
			end
			
			--[[

			]]
			-- debug mode
			if (HotLoot:getLootDebug() == true) then
				--print("---------------");
				print("Slot " .. curSlot .. ": " .. itemName);
				print("Item type: " .. itemType);
				print("Item sub type: " .. itemSubType);
				print("Looted: " .. tostring(isLooted));
				print("---------------");
			end
			
			if (isLooted == true) and (HotLoot:getLootEnableMonitor() == true) then
				local itoadd = HotLoot:addLootIcon(itemTexture, itemName, itemLink, lootQuantity);
				--icons[itemName] = itoadd;
				table.insert(icons, 1, itoadd);
				tStart = GetTime();
				itoadd = nil;
				
				HotLoot:UpdateMonitor();
			end
			
			-- next slot
			curSlot = curSlot + 1;
			
		
			--[[
				
			]]
			
		end
		
		-- close window
		dBug("ctrlDown", ctrlDown);
		
		if (HotLoot:getLootClose() == true) and (keyDown == nil) then
			CloseLoot();
		end
		
		
		
		--mainFrame:Show();
	end
end
frame:SetScript("OnEvent", eventHandler);

function DeleteJunk(iName)
	if HotLoot:getLootJunkDel() == true then
		for b = 0, 4 do 
			for s = 1, GetContainerNumSlots(b) do 
				local l = GetContainerItemLink(b, s) 
				if l and l:find(iName) then 
					PickupContainerItem(b, s);
					DeleteCursorItem();
					print(iName .. " deleted");
				end
			end
		end
	end
end

--		SAVE FOR DEBUG





-- set/get functions

-- lootEnabled
function HotLoot:setLootEnabled(info, value)
	self.db.char.lootEnabled = value;
	dBug("lootEnabled", value);
end
function HotLoot:getLootEnabled(info)
	return self.db.char.lootEnabled;
end

-- lootEnableMonitor
function HotLoot:setLootEnableMonitor(info, value)
	self.db.char.lootEnableMonitor = value;
	dBug("lootEnableMonitor", value);
end
function HotLoot:getLootEnableMonitor(info)
	return self.db.char.lootEnableMonitor;
end

-- lootShowAnchor
function HotLoot:setLootShowAnchor(info, value)
	self.db.char.lootShowAnchor = value;
	dBug("lootShowAnchor", value);
	HotLoot:ToggleAnchor(value);
end
function HotLoot:getLootShowAnchor(info)
	return self.db.char.lootShowAnchor;
end

-- lootShowNames
function HotLoot:setLootShowNames(info, value)
	self.db.char.lootShowNames = value;
	dBug("lootShowNames", value);
end
function HotLoot:getLootShowNames(info)
	return self.db.char.lootShowNames;
end

-- lootShowQuantities
function HotLoot:setLootShowQuantities(info, value)
	self.db.char.lootShowQuantities = value;
	dBug("lootShowQuantities", value);
end
function HotLoot:getLootShowQuantities(info)
	return self.db.char.lootShowQuantities;
end

-- lootIconSize
function HotLoot:setLootIconSize(info, value)
	self.db.char.lootIconSize = value;
	dBug("lootIconSize", value);
end
function HotLoot:getLootIconSize(info)
	return self.db.char.lootIconSize;
end

-- lootGrowthDirection
function HotLoot:setLootGrowthDirection(info, value)
	self.db.char.lootGrowthDirection = value;
	dBug("lootGrowthDirection", value);
end
function HotLoot:getLootGrowthDirection(info)
	return self.db.char.lootGrowthDirection;
end

-- lootGridMode
function HotLoot:setLootGridMode(info, value)
	self.db.char.lootGridMode = value;
	dBug("lootGridMode", value);
end
function HotLoot:getLootGridMode(info)
	return self.db.char.lootGridMode;
end

function HotLoot:ToggleGridDisable()
	local namesChecked = HotLoot:getLootShowNames();
	if namesChecked == true then
		--self.options.args.goupLootMonitor.lootGridMode:SetDisabled(true);
		HotLoot:setLootGridMode(false);
		return true;
	else
		--self.options.args.goupLootMonitor.lootGridMode:SetDisabled(false);
		return false;
	end
end

-- lootGridNumColumns
function HotLoot:setLootGridNumColumns(info, value)
	self.db.char.lootGridNumColumns = value;
	dBug("lootGridNumColumns", value);
end
function HotLoot:getLootGridNumColumns(info)
	return self.db.char.lootGridNumColumns;
end

-- TestMonitor
function HotLoot:TestMonitor()
	local itemName, itemLink, itemRarity, itemLevel, itemMinLevel, itemType, itemSubType, itemStackCount, itemEquipLoc, itemTexture, itemSellPrice = GetItemInfo(6948);
	local itoadd = HotLoot:addLootIcon(itemTexture, itemName, itemLink, 5);
	table.insert(icons, 1, itoadd);
	tStart = GetTime();
	itoadd = nil;
	itemName, itemLink, itemRarity, itemLevel, itemMinLevel, itemType, itemSubType, itemStackCount, itemEquipLoc, itemTexture, itemSellPrice = nil;			
	HotLoot:UpdateMonitor();
end

-- ResetMonitor
function HotLoot:ResetMonitor()
	HotLoot.mainFrame:ClearAllPoints();
	HotLoot.mainFrame:SetPoint("CENTER", 0, 0);
	HotLoot:UpdateMonitor();
	print("|cFFCD6600HotLoot|r: Anchor position reset.");
end

-- lootGold
function HotLoot:setLootGold(info, value)
	self.db.char.lootGold = value;
	dBug("lootGold", value);
end
function HotLoot:getLootGold(info)
	return self.db.char.lootGold;
end

-- lootQuest
function HotLoot:setLootQuest(info, value)
	self.db.char.lootQuest = value;
	dBug("lootQuest", value);
end
function HotLoot:getLootQuest(info)
	return self.db.char.lootQuest;
end

-- lootJunk
function HotLoot:setLootJunk(info, value)
	self.db.char.lootJunk = value;
	dBug("lootJunk", value);
end
function HotLoot:getLootJunk(info)
	return self.db.char.lootJunk;
end

-- lootJunkDel
function HotLoot:setLootJunkDel(info, value)
	self.db.char.lootJunkDel = value;
	dBug("lootJunkDel", value);
end
function HotLoot:getLootJunkDel(info)
	return self.db.char.lootJunkDel;
end

-- lootDebug
function HotLoot:setLootDebug(info, value)
	self.db.char.lootDebug = value;
	dBug("lootDebug", value);
end
function HotLoot:getLootDebug(info)
	return self.db.char.lootDebug;
end

-- lootClose
function HotLoot:setLootClose(info, value)
	self.db.char.lootClose = value;
	dBug("lootClose", value);
end
function HotLoot:getLootClose(info)
	return self.db.char.lootClose;
end

-- lootCloseKey
function HotLoot:setLootCloseKey(info, value)
	self.db.char.lootCloseKey = value;
	dBug("lootCloseKey", value);
end
function HotLoot:getLootCloseKey(info)
	return self.db.char.lootCloseKey;
end

--lootCloth
function HotLoot:setLootCloth(info, value)
	self.db.char.lootCloth = value;
	dBug("lootCloth", value);
end
function HotLoot:getLootCloth(info)
	return self.db.char.lootCloth;
end

--lootMining
function HotLoot:setLootMining(info, value)
	self.db.char.lootMining = value;
	dBug("lootMining", value);
end
function HotLoot:getLootMining(info)
	return self.db.char.lootMining;
end

--lootOre
--[[function HotLoot:setLootOre(info, value)
	self.db.char.lootOre = value;
	dBug("lootOre", value);
end
function HotLoot:getLootOre(info)
	return self.db.char.lootOre;
end

--lootStone
function HotLoot:setLootStone(info, value)
	self.db.char.lootStone = value;
	dBug("lootStone", value);
end
function HotLoot:getLootStone(info)
	return self.db.char.lootStone;
end
]]
--lootGems
function HotLoot:setLootGems(info, value)
	self.db.char.lootGems = value;
	dBug("lootGems", value);
end
function HotLoot:getLootGems(info)
	return self.db.char.lootGems;
end

--lootHerbs
function HotLoot:setLootHerbs(info, value)
	self.db.char.lootHerbs = value;
	dBug("lootHerbs", value);
end
function HotLoot:getLootHerbs(info)
	return self.db.char.lootHerbs;
end

--lootSkinning
function HotLoot:setLootSkinning(info, value)
	self.db.char.lootSkinning = value;
	dBug("lootSkinning", value);
end
function HotLoot:getLootSkinning(info)
	return self.db.char.lootSkinning;
end

-- lootFishing
function HotLoot:setLootFishing(info, value)
	self.db.char.lootFishing = value;
	dBug("lootFishing", value);
end
function HotLoot:getLootFishing(info)
	return self.db.char.lootFishing;
end

-- lootPots
function HotLoot:setLootPots(info, value)
	self.db.char.lootPots = value;
	dBug("lootPots", value);
end
function HotLoot:getLootPots(info)
	return self.db.char.lootPots;
end

-- lootMoH
function HotLoot:setLootMoH(info, value)
	self.db.char.lootMoH = value;
	dBug("lootMoH", value);
end
function HotLoot:getLootMoH(info)
	return self.db.char.lootMoH;
end

-- excludeList
function HotLoot:setExcludeList(info, value)
	self.db.char.excludeList = value;
	dBug("excludeList", value);
end
function HotLoot:getExcludeList(info)
	return self.db.char.excludeList;
end

-- includeList
function HotLoot:setIncludeList(info, value)
	self.db.char.includeList = value;
	dBug("includeList", value);
end
function HotLoot:getIncludeList(info)
	return self.db.char.includeList;
end

-- setLootElemental
function HotLoot:setLootElemental(info, value)
	self.db.char.lootElemental = value;
	dBug("lootElemental", value);
end
function HotLoot:getLootElemental(info)
	return self.db.char.lootElemental;
end

--lootGreen
function HotLoot:setLootGreen(info, value)
	self.db.char.lootGreen = value;
	dBug("lootGreen", value);
end
function HotLoot:getLootGreen(info)
	return self.db.char.lootGreen;
end

--lootGreenConfirm
function HotLoot:setLootGreenConfirm(info, value)
	self.db.char.lootGreenConfirm = value;
	dBug("lootGreenConfirm", value);
end
function HotLoot:getLootGreenConfirm(info)
	return self.db.char.lootGreenConfirm;
end

--lootBlue
function HotLoot:setLootBlue(info, value)
	self.db.char.lootBlue = value;
	dBug("lootBlue", value);
end
function HotLoot:getLootBlue(info)
	return self.db.char.lootBlue;
end

--lootBlueConfirm
function HotLoot:setLootBlueConfirm(info, value)
	self.db.char.lootBlueConfirm = value;
	dBug("lootBlueConfirm", value);
end
function HotLoot:getLootBlueConfirm(info)
	return self.db.char.lootBlueConfirm;
end

--lootCurrency
function HotLoot:setLootCurrency(info, value)
	self.db.char.lootCurrency = value;
	dBug("lootCurrency", value);
end
function HotLoot:getLootCurrency(info)
	return self.db.char.lootCurrency;
end


-- ######## ICON WIDGET ##########

function HotLoot:ToggleAnchor(val)
	if val then
		HotLoot:ShowAnchor();
	else
		HotLoot:HideAnchor();
	end
end

function HotLoot:ShowAnchor()
	HotLoot.mainFrame:SetAlpha(1);
end

function HotLoot:HideAnchor()
	HotLoot.mainFrame:SetAlpha(0);
end


function HotLoot:UpdateMonitor()
	local i = 1;
	local yOffset;
	local xOffset;
	local row, column = 0, 0;
	if (HotLoot:getLootGridMode() == true) and (HotLoot:getLootShowNames() == false) then
		while i <= #icons do
			
			xOffset = column * HotLoot:getLootIconSize(); --0, 32, 64, 96
			yOffset = ((row + 1) * (HotLoot:getLootIconSize() * HotLoot:getLootGrowthDirection())); --0, 0, 0, 0, 
			icons[i]:SetPoint("CENTER", HotLoot.mainFrame, "CENTER", xOffset, yOffset);
			i = i + 1;
			if column < (HotLoot:getLootGridNumColumns() - 1) then
				column = column + 1;
			else 
				row = row + 1;
				column = 0;
			end
		end
	else
		while i <= #icons do
			yOffset = (i * (HotLoot:getLootIconSize() * HotLoot:getLootGrowthDirection()));
			icons[i]:SetPoint("CENTER", HotLoot.mainFrame, "CENTER", 0, yOffset);
			i = i + 1;
		end
	end	
end

function ClearTooltips()
	GameTooltip:Hide();
	
	--HotLoot:UpdateMonitor();
end

function ShowTooltip(self)
	if self.item then
		GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
		GameTooltip:SetHyperlink(self.item);
		--CursorUpdate(self);
		GameTooltip:Show();
	end
end

function OnEnter(self)
	mouse_focus = self;
	--[[
	if self._highlights then
		self.icon_frame:ShowHighlight()
	end
	]]
	--GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
	--GameTooltip:SetHyperlink(self.item);
	
	self:ShowTooltip();
end

function OnLeave(self)
	mouse_focus = nil;
	--[[
	if self._highlights then
		self.icon_frame:HideHighlight();
	end
	]]
	--GameTooltip:Hide();
	--GameTooltip:ClearLines();
	ClearTooltips();
	ResetCursor();
end

function HotLoot:addLootIcon(iPath, iName, iLink, iCount)
	--local xslot = #icons;
	--local yOffset = xslot * -32;
	local icon = self.createLootIcon(iPath, iName, iLink, iCount)
	--icon:SetParent
	icon:Show();
	
	return icon;
end
--HotLoot.itemNNN = nil;
function HotLoot.createLootIcon(iPath, iName, iLink, iCount)
	local frame = CreateFrame("Frame", iName);
	local size = HotLoot:getLootIconSize();
	frame:SetFrameStrata("BACKGROUND");
	frame:SetWidth(size);
	frame:SetHeight(size);
	--frame:EnableMouse(true);
	frame.texture = icon;
	frame.item = iLink;
	frame.ShowTooltip = ShowTooltip;
	--frame:SetPoint("CENTER", HotLoot.mainFrame, "CENTER", 0, yOffset);
	frame:SetAlpha(1);
	if iCount > 0 then
		frame:SetScript("OnEnter", OnEnter);
		frame:SetScript("OnLeave", OnLeave);
	end
	--frame:SetScript("OnUpdate", FadeItem);
	--[[
	frame:RegisterForDrag("LeftButton");
	frame:SetMovable(true);
	frame:EnableMouse(true);
	frame:SetScript("OnDragStart", frame.StartMoving);
	frame:SetScript("OnDragStop", frame.StopMovingOrSizing);
	]]
	local icon = frame:CreateTexture(nil,"LOW");
	icon:SetAllPoints(frame);
	icon:SetTexture(iPath);
	
	local count = frame:CreateFontString(nil, "OVERLAY");
	count:SetPoint("BOTTOMRIGHT", frame, "BOTTOMRIGHT", -2, 2);
	count:SetFont(STANDARD_TEXT_FONT, 11, "OUTLINE");
	--count:SetText("x"..iCount);
	
	local name = frame:CreateFontString(nil, "OVERLAY");
	name:SetPoint("LEFT", frame, "RIGHT", 5, 0);
	name:SetFont(STANDARD_TEXT_FONT, 9, "OUTLINE");
	--name:SetJustifyH("LEFT");
	--name:SetText(iLink);
	--GameTooltip:SetHyperlink(iLink)
	--frame:Show();
	if HotLoot:getLootShowNames() == true then
		if iCount == 0 then
			name:SetText(iName);
		else
			name:SetText(iLink);
		end
	end
	if HotLoot:getLootShowQuantities() == true then
		if iCount > 1 then
			count:SetText("x"..iCount);
		end
	end
	
	return frame;
end

local isFirst;
isFirst = 0;
function FadeItems()

	
--[[	local tTotal = 0;
	local tEnd = delay;
	local function FadeItem(self,elapsed)
		tTotal = tTotal + elapsed;
		if tTotal >= tEnd then
			UIFrameFadeOut(itemName, fadeSeconds, 1, 0);
			icons.itemName.fadeInfo.finishedFunc(table.remove(icons, itemName));
		end
	end
 ]]
	--local f = CreateFrame("frame");
	--f:SetScript("OnUpdate", FadeItems);
		
	local iframe, alpha, fDelay;
	if (isFirst == 0) then
		isFirst = 0;
		fDelay = 5;
	else
		fDelay = 1;
	end
	if (icons[#icons] == nil) then
		isFirst = 0;
	end
	if (icons[#icons] ~= nil) and (tStart < (GetTime() - fDelay)) then
			iframe = icons[#icons];
			alpha = iframe:GetAlpha();
			--if (alpha == nil) then
				--alpha = icons[#icons]:GetAlpha();
			if (alpha ~= 0) then 
				iframe:SetAlpha(alpha - .05);
			elseif (alpha <= 0) then 
				--icons[#icons]:SetHyperlink(nil);
				iframe:Hide();
				table.remove(icons);
				dBug("#icons", #icons);
				--ClearTooltips();
				--GameTooltip:ClearAllPoints();
				--GameTooltip:ClearLines();
				--HotLoot:UpdateMonitor();		--MAYBE?
				tStart = GetTime();
				
				isFirst = isFirst + 1;
				dBug("isFirst", isFirst);
				dBug("fDelay", fDelay);
			end
	end
end
--HotLoot.mainFrame:SetScript("OnUpdate", FadeItems);